summaryrefslogtreecommitdiffhomepage
path: root/Opcode/Ice/IceLSS.h
diff options
context:
space:
mode:
Diffstat (limited to 'Opcode/Ice/IceLSS.h')
-rw-r--r--Opcode/Ice/IceLSS.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/Opcode/Ice/IceLSS.h b/Opcode/Ice/IceLSS.h
index c16c29f..8c2c154 100644
--- a/Opcode/Ice/IceLSS.h
+++ b/Opcode/Ice/IceLSS.h
@@ -32,13 +32,13 @@
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**
* Tests if a point is contained within the LSS.
* \param pt [in] the point to test
* \return true if inside the LSS
* \warning point and LSS must be in same space
*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
- inline_ bool Contains(const Point& pt) const { return SquareDistance(pt) <= mRadius*mRadius; }
+ inline_ bool Contains(const IcePoint& pt) const { return SquareDistance(pt) <= mRadius*mRadius; }
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**
@@ -32,13 +32,13 @@
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**
- * Tests if a point is contained within the LSS.
- * \param pt [in] the point to test
+ * Tests if a IcePoint is contained within the LSS.
+ * \param pt [in] the IcePoint to test
* \return true if inside the LSS
@@ -32,13 +32,13 @@
* \return true if inside the LSS
- * \warning point and LSS must be in same space
+ * \warning IcePoint and LSS must be in same space
*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////